@@ -4,7 +4,7 @@
     symbolx
     copyright 2022, Carlos Gaete-Morales, DIW-Berlin 
 """
-__version__ = (0, 1, 1)
+__version__ = (0, 1, 2)
 __author__ = 'Carlos Gaete-Morales'
 
 
@@ -12,7 +12,7 @@ from .parsers.parser_csv import symbol_parser_csv, load_csv
 from .parsers.parser_feather import symbol_parser_feather, load_feather
 from .parsers.parser_gdx import symbol_parser_gdx, load_gdx
 from .handler import DataCollection, SymbolsHandler
-from .utils import compress_subdirs, compress_dir
+from .utils import compress_subdirs, compress_dir, unzip_all, unzip
 from .symbols import Symbol, from_feather
 
 
